@@ -32,6 +32,7 @@
 #  Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
 # ---------------------------------------------------------------------------
 import math
+import datetime
 from .GXDLMSObject import GXDLMSObject
 from .IGXDLMSBase import IGXDLMSBase
 from ..enums import ErrorCode
@@ -73,6 +74,19 @@ class GXDLMSExtendedRegister(GXDLMSObject, IGXDLMSBase):
                 self.status,
                 self.captureTime]
 
+    def reset(self, client):
+        """Reset value."""
+        return client.method(self.getName(), self.objectType, 1, 0, DataType.INT8)
+
+    def invoke(self, settings, e):
+        #  Resets the value to the default value.
+        #  The default value is an instance specific constant.
+        if e.index == 1:
+            self.value = None
+            self.captureTime = datetime.datetime.now()
+        else:
+            e.error = ErrorCode.READ_WRITE_DENIED
+
     #
     #      Returns collection of attributes to read.  If attribute is static
     #      and
@@ -165,14 +179,14 @@ class GXDLMSExtendedRegister(GXDLMSObject, IGXDLMSBase):
             #  Set default values.
             if not e.value:
                 self.scaler = 0
-                self.unit = 0
+                self.unit = Unit.NONE
             else:
                 if not e.value:
                     self.scaler = 0
-                    self.unit = 0
+                    self.unit = Unit.NONE
                 else:
                     self.scaler = math.pow(10, e.value[0])
-                    self.unit = e.value[1]
+                    self.unit = Unit(e.value[1])
         elif e.index == 4:
             self.status = e.value
         elif e.index == 5:
@@ -194,7 +208,7 @@ class GXDLMSExtendedRegister(GXDLMSObject, IGXDLMSBase):
         self.captureTime = reader.readElementContentAsDateTime("CaptureTime")
 
     def save(self, writer):
-        writer.writeElementString("Unit", self.unit)
+        writer.writeElementString("Unit", int(self.unit))
         writer.writeElementString("Scaler", self.scaler, 1)
         writer.writeElementObject("Value", self.value, self.getDataType(2), self.getUIDataType(2))
         writer.writeElementObject("Status", self.status, self.getDataType(4), self.getUIDataType(4))
